aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/Utils.h
diff options
context:
space:
mode:
authorMichalis Spyrou <michalis.spyrou@arm.com>2017-11-23 09:49:51 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:42:33 +0000
commit780db4eb6a9e3dee565d14f36d772038cd3253da (patch)
tree53490d6a03bdeb26d77bc8840d1dbf6027e81f5c /arm_compute/core/Utils.h
parentd7ba5397b676c966cb5069c7187a12a0c35305f5 (diff)
downloadComputeLibrary-780db4eb6a9e3dee565d14f36d772038cd3253da.tar.gz
COMPMID-471 Implement Deconvolution on OpenCL
Change-Id: Ie00c6b08a51d30c5ce2637d40ee3d165b8a68686 Reviewed-on: https://eu-gerrit-1.euhpc.arm.com/110311 Reviewed-by: Pablo Tello <pablo.tello@arm.com> Reviewed-by: Georgios Pinitas <georgios.pinitas@arm.com> Tested-by: Jenkins <bsgcomp@arm.com>
Diffstat (limited to 'arm_compute/core/Utils.h')
-rw-r--r--arm_compute/core/Utils.h28
1 files changed, 13 insertions, 15 deletions
diff --git a/arm_compute/core/Utils.h b/arm_compute/core/Utils.h
index f78add13f9..51967b1762 100644
--- a/arm_compute/core/Utils.h
+++ b/arm_compute/core/Utils.h
@@ -1,5 +1,5 @@
/*
- * Copyright (c) 2016, 2017 ARM Limited.
+ * Copyright (c) 2016, 2017, 2018 ARM Limited.
*
* SPDX-License-Identifier: MIT
*
@@ -614,25 +614,23 @@ TensorShape deconvolution_output_shape(const std::pair<unsigned int, unsigned in
/** Returns expected width and height of the deconvolution's output tensor.
*
* @param[in] in_width Width of input tensor (Number of columns)
* @param[in] in_height Height of input tensor (Number of rows)
* @param[in] kernel_width Kernel width.
* @param[in] kernel_height Kernel height.
* @param[in] padx X axis padding.
* @param[in] pady Y axis padding.
* @param[in] ax The number of zeros added to right edge of the input.
* @param[in] ay The number of zeros added to top edge of the input.
* @param[in] upscalex How much to scale the X axis.
* @param[in] upscaley How much to scale the Y axis.
* @param[in] round Rounding policy to be used when computing the output's dimensions.
*
* @return A pair with the new width in the first position and the new height in the second.
*/
-
const std::pair<unsigned int, unsigned int> deconvolution_output_dimensions(unsigned int in_width, unsigned int in_height,
unsigned int kernel_width, unsigned int kernel_height,
- unsigned int padx, unsigned int pady, unsigned int ax, unsigned int ay,
- float upscalex, float upscaley, DimensionRoundingType round);
+ unsigned int padx, unsigned int pady, unsigned int inner_border_right, unsigned int inner_border_top,
+ unsigned int stride_x, unsigned int stride_y);
/** Returns expected width and height of output scaled tensor depending on dimensions rounding mode.
*
@@ -614,25 +614,23 @@ TensorShape deconvolution_output_shape(const std::pair<unsigned int, unsigned in
/** Returns expected width and height of the deconvolution's output tensor.
*
- * @param[in] in_width Width of input tensor (Number of columns)
- * @param[in] in_height Height of input tensor (Number of rows)
- * @param[in] kernel_width Kernel width.
- * @param[in] kernel_height Kernel height.
- * @param[in] padx X axis padding.
- * @param[in] pady Y axis padding.
- * @param[in] ax The number of zeros added to right edge of the input.
- * @param[in] ay The number of zeros added to top edge of the input.
- * @param[in] upscalex How much to scale the X axis.
- * @param[in] upscaley How much to scale the Y axis.
- * @param[in] round Rounding policy to be used when computing the output's dimensions.
+ * @param[in] in_width Width of input tensor (Number of columns)
+ * @param[in] in_height Height of input tensor (Number of rows)
+ * @param[in] kernel_width Kernel width.
+ * @param[in] kernel_height Kernel height.
+ * @param[in] padx X axis padding.
+ * @param[in] pady Y axis padding.
+ * @param[in] inner_border_right The number of zeros added to right edge of the input.
+ * @param[in] inner_border_top The number of zeros added to top edge of the input.
+ * @param[in] stride_x X axis input stride.
+ * @param[in] stride_y Y axis input stride.
*
* @return A pair with the new width in the first position and the new height in the second.